@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "khalel" "0.1.15"
+(define-package "khalel" "20250910.946"
   "Import, edit and create calendar events through khal."
   '((emacs "27.1"))
   :url "https://gitlab.com/hperrey/khalel"
